@@ -1,7 +1,7 @@
 """
 Type annotations for wisdom service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_wisdom/type_defs/)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_wisdom/type_defs/)
 
 Usage::
 
@@ -15,13 +15,12 @@ import sys
 from datetime import datetime
 from typing import Dict, List, Mapping, Sequence
 
-from typing_extensions import NotRequired
-
 from .literals import (
     AssistantStatusType,
     ContentStatusType,
     KnowledgeBaseStatusType,
     KnowledgeBaseTypeType,
+    RecommendationSourceTypeType,
     RelevanceLevelType,
 )
 
@@ -102,7 +101,10 @@ __all__ = (
     "QueryAssistantRequestQueryAssistantPaginateTypeDef",
     "QueryAssistantRequestRequestTypeDef",
     "QueryAssistantResponseTypeDef",
+    "QueryRecommendationTriggerDataTypeDef",
     "RecommendationDataTypeDef",
+    "RecommendationTriggerDataTypeDef",
+    "RecommendationTriggerTypeDef",
     "RemoveKnowledgeBaseTemplateUriRequestRequestTypeDef",
     "RenderingConfigurationTypeDef",
     "ResponseMetadataTypeDef",
@@ -136,8 +138,8 @@ AppIntegrationsConfigurationTypeDef = TypedDict(
     },
 )
 
-AssistantAssociationDataTypeDef = TypedDict(
-    "AssistantAssociationDataTypeDef",
+_RequiredAssistantAssociationDataTypeDef = TypedDict(
+    "_RequiredAssistantAssociationDataTypeDef",
     {
         "assistantArn": str,
         "assistantAssociationArn": str,
@@ -145,26 +147,41 @@ AssistantAssociationDataTypeDef = TypedDict(
         "assistantId": str,
         "associationData": "AssistantAssociationOutputDataTypeDef",
         "associationType": Literal["KNOWLEDGE_BASE"],
-        "tags": NotRequired[Dict[str, str]],
     },
 )
+_OptionalAssistantAssociationDataTypeDef = TypedDict(
+    "_OptionalAssistantAssociationDataTypeDef",
+    {
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
+
+
+class AssistantAssociationDataTypeDef(
+    _RequiredAssistantAssociationDataTypeDef, _OptionalAssistantAssociationDataTypeDef
+):
+    pass
+
 
 AssistantAssociationInputDataTypeDef = TypedDict(
     "AssistantAssociationInputDataTypeDef",
     {
-        "knowledgeBaseId": NotRequired[str],
+        "knowledgeBaseId": str,
     },
+    total=False,
 )
 
 AssistantAssociationOutputDataTypeDef = TypedDict(
     "AssistantAssociationOutputDataTypeDef",
     {
-        "knowledgeBaseAssociation": NotRequired["KnowledgeBaseAssociationDataTypeDef"],
+        "knowledgeBaseAssociation": "KnowledgeBaseAssociationDataTypeDef",
     },
+    total=False,
 )
 
-AssistantAssociationSummaryTypeDef = TypedDict(
-    "AssistantAssociationSummaryTypeDef",
+_RequiredAssistantAssociationSummaryTypeDef = TypedDict(
+    "_RequiredAssistantAssociationSummaryTypeDef",
     {
         "assistantArn": str,
         "assistantAssociationArn": str,
@@ -172,44 +189,75 @@ AssistantAssociationSummaryTypeDef = TypedDict(
         "assistantId": str,
         "associationData": "AssistantAssociationOutputDataTypeDef",
         "associationType": Literal["KNOWLEDGE_BASE"],
-        "tags": NotRequired[Dict[str, str]],
     },
 )
+_OptionalAssistantAssociationSummaryTypeDef = TypedDict(
+    "_OptionalAssistantAssociationSummaryTypeDef",
+    {
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
 
-AssistantDataTypeDef = TypedDict(
-    "AssistantDataTypeDef",
+
+class AssistantAssociationSummaryTypeDef(
+    _RequiredAssistantAssociationSummaryTypeDef, _OptionalAssistantAssociationSummaryTypeDef
+):
+    pass
+
+
+_RequiredAssistantDataTypeDef = TypedDict(
+    "_RequiredAssistantDataTypeDef",
     {
         "assistantArn": str,
         "assistantId": str,
         "name": str,
         "status": AssistantStatusType,
         "type": Literal["AGENT"],
-        "description": NotRequired[str],
-        "serverSideEncryptionConfiguration": NotRequired[
-            "ServerSideEncryptionConfigurationTypeDef"
-        ],
-        "tags": NotRequired[Dict[str, str]],
     },
 )
+_OptionalAssistantDataTypeDef = TypedDict(
+    "_OptionalAssistantDataTypeDef",
+    {
+        "description": str,
+        "serverSideEncryptionConfiguration": "ServerSideEncryptionConfigurationTypeDef",
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
 
-AssistantSummaryTypeDef = TypedDict(
-    "AssistantSummaryTypeDef",
+
+class AssistantDataTypeDef(_RequiredAssistantDataTypeDef, _OptionalAssistantDataTypeDef):
+    pass
+
+
+_RequiredAssistantSummaryTypeDef = TypedDict(
+    "_RequiredAssistantSummaryTypeDef",
     {
         "assistantArn": str,
         "assistantId": str,
         "name": str,
         "status": AssistantStatusType,
         "type": Literal["AGENT"],
-        "description": NotRequired[str],
-        "serverSideEncryptionConfiguration": NotRequired[
-            "ServerSideEncryptionConfigurationTypeDef"
-        ],
-        "tags": NotRequired[Dict[str, str]],
     },
 )
+_OptionalAssistantSummaryTypeDef = TypedDict(
+    "_OptionalAssistantSummaryTypeDef",
+    {
+        "description": str,
+        "serverSideEncryptionConfiguration": "ServerSideEncryptionConfigurationTypeDef",
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
 
-ContentDataTypeDef = TypedDict(
-    "ContentDataTypeDef",
+
+class AssistantSummaryTypeDef(_RequiredAssistantSummaryTypeDef, _OptionalAssistantSummaryTypeDef):
+    pass
+
+
+_RequiredContentDataTypeDef = TypedDict(
+    "_RequiredContentDataTypeDef",
     {
         "contentArn": str,
         "contentId": str,
@@ -223,23 +271,35 @@ ContentDataTypeDef = TypedDict(
         "title": str,
         "url": str,
         "urlExpiry": datetime,
-        "linkOutUri": NotRequired[str],
-        "tags": NotRequired[Dict[str, str]],
     },
 )
+_OptionalContentDataTypeDef = TypedDict(
+    "_OptionalContentDataTypeDef",
+    {
+        "linkOutUri": str,
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
+
+
+class ContentDataTypeDef(_RequiredContentDataTypeDef, _OptionalContentDataTypeDef):
+    pass
+
 
 ContentReferenceTypeDef = TypedDict(
     "ContentReferenceTypeDef",
     {
-        "contentArn": NotRequired[str],
-        "contentId": NotRequired[str],
-        "knowledgeBaseArn": NotRequired[str],
-        "knowledgeBaseId": NotRequired[str],
+        "contentArn": str,
+        "contentId": str,
+        "knowledgeBaseArn": str,
+        "knowledgeBaseId": str,
     },
+    total=False,
 )
 
-ContentSummaryTypeDef = TypedDict(
-    "ContentSummaryTypeDef",
+_RequiredContentSummaryTypeDef = TypedDict(
+    "_RequiredContentSummaryTypeDef",
     {
         "contentArn": str,
         "contentId": str,
@@ -251,20 +311,45 @@ ContentSummaryTypeDef = TypedDict(
         "revisionId": str,
         "status": ContentStatusType,
         "title": str,
-        "tags": NotRequired[Dict[str, str]],
     },
 )
+_OptionalContentSummaryTypeDef = TypedDict(
+    "_OptionalContentSummaryTypeDef",
+    {
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
 
-CreateAssistantAssociationRequestRequestTypeDef = TypedDict(
-    "CreateAssistantAssociationRequestRequestTypeDef",
+
+class ContentSummaryTypeDef(_RequiredContentSummaryTypeDef, _OptionalContentSummaryTypeDef):
+    pass
+
+
+_RequiredCreateAssistantAssociationRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateAssistantAssociationRequestRequestTypeDef",
     {
         "assistantId": str,
         "association": "AssistantAssociationInputDataTypeDef",
         "associationType": Literal["KNOWLEDGE_BASE"],
-        "clientToken": NotRequired[str],
-        "tags": NotRequired[Mapping[str, str]],
     },
 )
+_OptionalCreateAssistantAssociationRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateAssistantAssociationRequestRequestTypeDef",
+    {
+        "clientToken": str,
+        "tags": Mapping[str, str],
+    },
+    total=False,
+)
+
+
+class CreateAssistantAssociationRequestRequestTypeDef(
+    _RequiredCreateAssistantAssociationRequestRequestTypeDef,
+    _OptionalCreateAssistantAssociationRequestRequestTypeDef,
+):
+    pass
+
 
 CreateAssistantAssociationResponseTypeDef = TypedDict(
     "CreateAssistantAssociationResponseTypeDef",
@@ -274,19 +359,30 @@ CreateAssistantAssociationResponseTypeDef = TypedDict(
     },
 )
 
-CreateAssistantRequestRequestTypeDef = TypedDict(
-    "CreateAssistantRequestRequestTypeDef",
+_RequiredCreateAssistantRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateAssistantRequestRequestTypeDef",
     {
         "name": str,
         "type": Literal["AGENT"],
-        "clientToken": NotRequired[str],
-        "description": NotRequired[str],
-        "serverSideEncryptionConfiguration": NotRequired[
-            "ServerSideEncryptionConfigurationTypeDef"
-        ],
-        "tags": NotRequired[Mapping[str, str]],
     },
 )
+_OptionalCreateAssistantRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateAssistantRequestRequestTypeDef",
+    {
+        "clientToken": str,
+        "description": str,
+        "serverSideEncryptionConfiguration": "ServerSideEncryptionConfigurationTypeDef",
+        "tags": Mapping[str, str],
+    },
+    total=False,
+)
+
+
+class CreateAssistantRequestRequestTypeDef(
+    _RequiredCreateAssistantRequestRequestTypeDef, _OptionalCreateAssistantRequestRequestTypeDef
+):
+    pass
+
 
 CreateAssistantResponseTypeDef = TypedDict(
     "CreateAssistantResponseTypeDef",
@@ -296,19 +392,32 @@ CreateAssistantResponseTypeDef = TypedDict(
     },
 )
 
-CreateContentRequestRequestTypeDef = TypedDict(
-    "CreateContentRequestRequestTypeDef",
+_RequiredCreateContentRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateContentRequestRequestTypeDef",
     {
         "knowledgeBaseId": str,
         "name": str,
         "uploadId": str,
-        "clientToken": NotRequired[str],
-        "metadata": NotRequired[Mapping[str, str]],
-        "overrideLinkOutUri": NotRequired[str],
-        "tags": NotRequired[Mapping[str, str]],
-        "title": NotRequired[str],
     },
 )
+_OptionalCreateContentRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateContentRequestRequestTypeDef",
+    {
+        "clientToken": str,
+        "metadata": Mapping[str, str],
+        "overrideLinkOutUri": str,
+        "tags": Mapping[str, str],
+        "title": str,
+    },
+    total=False,
+)
+
+
+class CreateContentRequestRequestTypeDef(
+    _RequiredCreateContentRequestRequestTypeDef, _OptionalCreateContentRequestRequestTypeDef
+):
+    pass
+
 
 CreateContentResponseTypeDef = TypedDict(
     "CreateContentResponseTypeDef",
@@ -318,21 +427,33 @@ CreateContentResponseTypeDef = TypedDict(
     },
 )
 
-CreateKnowledgeBaseRequestRequestTypeDef = TypedDict(
-    "CreateKnowledgeBaseRequestRequestTypeDef",
+_RequiredCreateKnowledgeBaseRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateKnowledgeBaseRequestRequestTypeDef",
     {
         "knowledgeBaseType": KnowledgeBaseTypeType,
         "name": str,
-        "clientToken": NotRequired[str],
-        "description": NotRequired[str],
-        "renderingConfiguration": NotRequired["RenderingConfigurationTypeDef"],
-        "serverSideEncryptionConfiguration": NotRequired[
-            "ServerSideEncryptionConfigurationTypeDef"
-        ],
-        "sourceConfiguration": NotRequired["SourceConfigurationTypeDef"],
-        "tags": NotRequired[Mapping[str, str]],
     },
 )
+_OptionalCreateKnowledgeBaseRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateKnowledgeBaseRequestRequestTypeDef",
+    {
+        "clientToken": str,
+        "description": str,
+        "renderingConfiguration": "RenderingConfigurationTypeDef",
+        "serverSideEncryptionConfiguration": "ServerSideEncryptionConfigurationTypeDef",
+        "sourceConfiguration": "SourceConfigurationTypeDef",
+        "tags": Mapping[str, str],
+    },
+    total=False,
+)
+
+
+class CreateKnowledgeBaseRequestRequestTypeDef(
+    _RequiredCreateKnowledgeBaseRequestRequestTypeDef,
+    _OptionalCreateKnowledgeBaseRequestRequestTypeDef,
+):
+    pass
+
 
 CreateKnowledgeBaseResponseTypeDef = TypedDict(
     "CreateKnowledgeBaseResponseTypeDef",
@@ -342,16 +463,29 @@ CreateKnowledgeBaseResponseTypeDef = TypedDict(
     },
 )
 
-CreateSessionRequestRequestTypeDef = TypedDict(
-    "CreateSessionRequestRequestTypeDef",
+_RequiredCreateSessionRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateSessionRequestRequestTypeDef",
     {
         "assistantId": str,
         "name": str,
-        "clientToken": NotRequired[str],
-        "description": NotRequired[str],
-        "tags": NotRequired[Mapping[str, str]],
     },
 )
+_OptionalCreateSessionRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateSessionRequestRequestTypeDef",
+    {
+        "clientToken": str,
+        "description": str,
+        "tags": Mapping[str, str],
+    },
+    total=False,
+)
+
+
+class CreateSessionRequestRequestTypeDef(
+    _RequiredCreateSessionRequestRequestTypeDef, _OptionalCreateSessionRequestRequestTypeDef
+):
+    pass
+
 
 CreateSessionResponseTypeDef = TypedDict(
     "CreateSessionResponseTypeDef",
@@ -394,19 +528,31 @@ DeleteKnowledgeBaseRequestRequestTypeDef = TypedDict(
 DocumentTextTypeDef = TypedDict(
     "DocumentTextTypeDef",
     {
-        "highlights": NotRequired[List["HighlightTypeDef"]],
-        "text": NotRequired[str],
+        "highlights": List["HighlightTypeDef"],
+        "text": str,
     },
+    total=False,
 )
 
-DocumentTypeDef = TypedDict(
-    "DocumentTypeDef",
+_RequiredDocumentTypeDef = TypedDict(
+    "_RequiredDocumentTypeDef",
     {
         "contentReference": "ContentReferenceTypeDef",
-        "excerpt": NotRequired["DocumentTextTypeDef"],
-        "title": NotRequired["DocumentTextTypeDef"],
     },
 )
+_OptionalDocumentTypeDef = TypedDict(
+    "_OptionalDocumentTypeDef",
+    {
+        "excerpt": "DocumentTextTypeDef",
+        "title": "DocumentTextTypeDef",
+    },
+    total=False,
+)
+
+
+class DocumentTypeDef(_RequiredDocumentTypeDef, _OptionalDocumentTypeDef):
+    pass
+
 
 FilterTypeDef = TypedDict(
     "FilterTypeDef",
@@ -495,20 +641,35 @@ GetKnowledgeBaseResponseTypeDef = TypedDict(
     },
 )
 
-GetRecommendationsRequestRequestTypeDef = TypedDict(
-    "GetRecommendationsRequestRequestTypeDef",
+_RequiredGetRecommendationsRequestRequestTypeDef = TypedDict(
+    "_RequiredGetRecommendationsRequestRequestTypeDef",
     {
         "assistantId": str,
         "sessionId": str,
-        "maxResults": NotRequired[int],
-        "waitTimeSeconds": NotRequired[int],
     },
 )
+_OptionalGetRecommendationsRequestRequestTypeDef = TypedDict(
+    "_OptionalGetRecommendationsRequestRequestTypeDef",
+    {
+        "maxResults": int,
+        "waitTimeSeconds": int,
+    },
+    total=False,
+)
+
+
+class GetRecommendationsRequestRequestTypeDef(
+    _RequiredGetRecommendationsRequestRequestTypeDef,
+    _OptionalGetRecommendationsRequestRequestTypeDef,
+):
+    pass
+
 
 GetRecommendationsResponseTypeDef = TypedDict(
     "GetRecommendationsResponseTypeDef",
     {
         "recommendations": List["RecommendationDataTypeDef"],
+        "triggers": List["RecommendationTriggerTypeDef"],
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
@@ -532,72 +693,124 @@ GetSessionResponseTypeDef = TypedDict(
 HighlightTypeDef = TypedDict(
     "HighlightTypeDef",
     {
-        "beginOffsetInclusive": NotRequired[int],
-        "endOffsetExclusive": NotRequired[int],
+        "beginOffsetInclusive": int,
+        "endOffsetExclusive": int,
     },
+    total=False,
 )
 
 KnowledgeBaseAssociationDataTypeDef = TypedDict(
     "KnowledgeBaseAssociationDataTypeDef",
     {
-        "knowledgeBaseArn": NotRequired[str],
-        "knowledgeBaseId": NotRequired[str],
+        "knowledgeBaseArn": str,
+        "knowledgeBaseId": str,
     },
+    total=False,
 )
 
-KnowledgeBaseDataTypeDef = TypedDict(
-    "KnowledgeBaseDataTypeDef",
+_RequiredKnowledgeBaseDataTypeDef = TypedDict(
+    "_RequiredKnowledgeBaseDataTypeDef",
     {
         "knowledgeBaseArn": str,
         "knowledgeBaseId": str,
         "knowledgeBaseType": KnowledgeBaseTypeType,
         "name": str,
         "status": KnowledgeBaseStatusType,
-        "description": NotRequired[str],
-        "lastContentModificationTime": NotRequired[datetime],
-        "renderingConfiguration": NotRequired["RenderingConfigurationTypeDef"],
-        "serverSideEncryptionConfiguration": NotRequired[
-            "ServerSideEncryptionConfigurationTypeDef"
-        ],
-        "sourceConfiguration": NotRequired["SourceConfigurationTypeDef"],
-        "tags": NotRequired[Dict[str, str]],
     },
 )
+_OptionalKnowledgeBaseDataTypeDef = TypedDict(
+    "_OptionalKnowledgeBaseDataTypeDef",
+    {
+        "description": str,
+        "lastContentModificationTime": datetime,
+        "renderingConfiguration": "RenderingConfigurationTypeDef",
+        "serverSideEncryptionConfiguration": "ServerSideEncryptionConfigurationTypeDef",
+        "sourceConfiguration": "SourceConfigurationTypeDef",
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
 
-KnowledgeBaseSummaryTypeDef = TypedDict(
-    "KnowledgeBaseSummaryTypeDef",
+
+class KnowledgeBaseDataTypeDef(
+    _RequiredKnowledgeBaseDataTypeDef, _OptionalKnowledgeBaseDataTypeDef
+):
+    pass
+
+
+_RequiredKnowledgeBaseSummaryTypeDef = TypedDict(
+    "_RequiredKnowledgeBaseSummaryTypeDef",
     {
         "knowledgeBaseArn": str,
         "knowledgeBaseId": str,
         "knowledgeBaseType": KnowledgeBaseTypeType,
         "name": str,
         "status": KnowledgeBaseStatusType,
-        "description": NotRequired[str],
-        "renderingConfiguration": NotRequired["RenderingConfigurationTypeDef"],
-        "serverSideEncryptionConfiguration": NotRequired[
-            "ServerSideEncryptionConfigurationTypeDef"
-        ],
-        "sourceConfiguration": NotRequired["SourceConfigurationTypeDef"],
-        "tags": NotRequired[Dict[str, str]],
     },
 )
+_OptionalKnowledgeBaseSummaryTypeDef = TypedDict(
+    "_OptionalKnowledgeBaseSummaryTypeDef",
+    {
+        "description": str,
+        "renderingConfiguration": "RenderingConfigurationTypeDef",
+        "serverSideEncryptionConfiguration": "ServerSideEncryptionConfigurationTypeDef",
+        "sourceConfiguration": "SourceConfigurationTypeDef",
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
 
-ListAssistantAssociationsRequestListAssistantAssociationsPaginateTypeDef = TypedDict(
-    "ListAssistantAssociationsRequestListAssistantAssociationsPaginateTypeDef",
+
+class KnowledgeBaseSummaryTypeDef(
+    _RequiredKnowledgeBaseSummaryTypeDef, _OptionalKnowledgeBaseSummaryTypeDef
+):
+    pass
+
+
+_RequiredListAssistantAssociationsRequestListAssistantAssociationsPaginateTypeDef = TypedDict(
+    "_RequiredListAssistantAssociationsRequestListAssistantAssociationsPaginateTypeDef",
     {
         "assistantId": str,
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
+_OptionalListAssistantAssociationsRequestListAssistantAssociationsPaginateTypeDef = TypedDict(
+    "_OptionalListAssistantAssociationsRequestListAssistantAssociationsPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
 
-ListAssistantAssociationsRequestRequestTypeDef = TypedDict(
-    "ListAssistantAssociationsRequestRequestTypeDef",
+
+class ListAssistantAssociationsRequestListAssistantAssociationsPaginateTypeDef(
+    _RequiredListAssistantAssociationsRequestListAssistantAssociationsPaginateTypeDef,
+    _OptionalListAssistantAssociationsRequestListAssistantAssociationsPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListAssistantAssociationsRequestRequestTypeDef = TypedDict(
+    "_RequiredListAssistantAssociationsRequestRequestTypeDef",
     {
         "assistantId": str,
-        "maxResults": NotRequired[int],
-        "nextToken": NotRequired[str],
     },
 )
+_OptionalListAssistantAssociationsRequestRequestTypeDef = TypedDict(
+    "_OptionalListAssistantAssociationsRequestRequestTypeDef",
+    {
+        "maxResults": int,
+        "nextToken": str,
+    },
+    total=False,
+)
+
+
+class ListAssistantAssociationsRequestRequestTypeDef(
+    _RequiredListAssistantAssociationsRequestRequestTypeDef,
+    _OptionalListAssistantAssociationsRequestRequestTypeDef,
+):
+    pass
+
 
 ListAssistantAssociationsResponseTypeDef = TypedDict(
     "ListAssistantAssociationsResponseTypeDef",
@@ -611,16 +824,18 @@ ListAssistantAssociationsResponseTypeDef = TypedDict(
 ListAssistantsRequestListAssistantsPaginateTypeDef = TypedDict(
     "ListAssistantsRequestListAssistantsPaginateTypeDef",
     {
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+        "PaginationConfig": "PaginatorConfigTypeDef",
     },
+    total=False,
 )
 
 ListAssistantsRequestRequestTypeDef = TypedDict(
     "ListAssistantsRequestRequestTypeDef",
     {
-        "maxResults": NotRequired[int],
-        "nextToken": NotRequired[str],
+        "maxResults": int,
+        "nextToken": str,
     },
+    total=False,
 )
 
 ListAssistantsResponseTypeDef = TypedDict(
@@ -632,22 +847,49 @@ ListAssistantsResponseTypeDef = TypedDict(
     },
 )
 
-ListContentsRequestListContentsPaginateTypeDef = TypedDict(
-    "ListContentsRequestListContentsPaginateTypeDef",
+_RequiredListContentsRequestListContentsPaginateTypeDef = TypedDict(
+    "_RequiredListContentsRequestListContentsPaginateTypeDef",
     {
         "knowledgeBaseId": str,
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
+_OptionalListContentsRequestListContentsPaginateTypeDef = TypedDict(
+    "_OptionalListContentsRequestListContentsPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
 
-ListContentsRequestRequestTypeDef = TypedDict(
-    "ListContentsRequestRequestTypeDef",
+
+class ListContentsRequestListContentsPaginateTypeDef(
+    _RequiredListContentsRequestListContentsPaginateTypeDef,
+    _OptionalListContentsRequestListContentsPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListContentsRequestRequestTypeDef = TypedDict(
+    "_RequiredListContentsRequestRequestTypeDef",
     {
         "knowledgeBaseId": str,
-        "maxResults": NotRequired[int],
-        "nextToken": NotRequired[str],
     },
 )
+_OptionalListContentsRequestRequestTypeDef = TypedDict(
+    "_OptionalListContentsRequestRequestTypeDef",
+    {
+        "maxResults": int,
+        "nextToken": str,
+    },
+    total=False,
+)
+
+
+class ListContentsRequestRequestTypeDef(
+    _RequiredListContentsRequestRequestTypeDef, _OptionalListContentsRequestRequestTypeDef
+):
+    pass
+
 
 ListContentsResponseTypeDef = TypedDict(
     "ListContentsResponseTypeDef",
@@ -661,16 +903,18 @@ ListContentsResponseTypeDef = TypedDict(
 ListKnowledgeBasesRequestListKnowledgeBasesPaginateTypeDef = TypedDict(
     "ListKnowledgeBasesRequestListKnowledgeBasesPaginateTypeDef",
     {
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+        "PaginationConfig": "PaginatorConfigTypeDef",
     },
+    total=False,
 )
 
 ListKnowledgeBasesRequestRequestTypeDef = TypedDict(
     "ListKnowledgeBasesRequestRequestTypeDef",
     {
-        "maxResults": NotRequired[int],
-        "nextToken": NotRequired[str],
+        "maxResults": int,
+        "nextToken": str,
     },
+    total=False,
 )
 
 ListKnowledgeBasesResponseTypeDef = TypedDict(
@@ -700,9 +944,10 @@ ListTagsForResourceResponseTypeDef = TypedDict(
 NotifyRecommendationsReceivedErrorTypeDef = TypedDict(
     "NotifyRecommendationsReceivedErrorTypeDef",
     {
-        "message": NotRequired[str],
-        "recommendationId": NotRequired[str],
+        "message": str,
+        "recommendationId": str,
     },
+    total=False,
 )
 
 NotifyRecommendationsReceivedRequestRequestTypeDef = TypedDict(
@@ -726,30 +971,58 @@ NotifyRecommendationsReceivedResponseTypeDef = TypedDict(
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
-        "MaxItems": NotRequired[int],
-        "PageSize": NotRequired[int],
-        "StartingToken": NotRequired[str],
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
     },
+    total=False,
 )
 
-QueryAssistantRequestQueryAssistantPaginateTypeDef = TypedDict(
-    "QueryAssistantRequestQueryAssistantPaginateTypeDef",
+_RequiredQueryAssistantRequestQueryAssistantPaginateTypeDef = TypedDict(
+    "_RequiredQueryAssistantRequestQueryAssistantPaginateTypeDef",
     {
         "assistantId": str,
         "queryText": str,
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
+_OptionalQueryAssistantRequestQueryAssistantPaginateTypeDef = TypedDict(
+    "_OptionalQueryAssistantRequestQueryAssistantPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
 
-QueryAssistantRequestRequestTypeDef = TypedDict(
-    "QueryAssistantRequestRequestTypeDef",
+
+class QueryAssistantRequestQueryAssistantPaginateTypeDef(
+    _RequiredQueryAssistantRequestQueryAssistantPaginateTypeDef,
+    _OptionalQueryAssistantRequestQueryAssistantPaginateTypeDef,
+):
+    pass
+
+
+_RequiredQueryAssistantRequestRequestTypeDef = TypedDict(
+    "_RequiredQueryAssistantRequestRequestTypeDef",
     {
         "assistantId": str,
         "queryText": str,
-        "maxResults": NotRequired[int],
-        "nextToken": NotRequired[str],
     },
 )
+_OptionalQueryAssistantRequestRequestTypeDef = TypedDict(
+    "_OptionalQueryAssistantRequestRequestTypeDef",
+    {
+        "maxResults": int,
+        "nextToken": str,
+    },
+    total=False,
+)
+
+
+class QueryAssistantRequestRequestTypeDef(
+    _RequiredQueryAssistantRequestRequestTypeDef, _OptionalQueryAssistantRequestRequestTypeDef
+):
+    pass
+
 
 QueryAssistantResponseTypeDef = TypedDict(
     "QueryAssistantResponseTypeDef",
@@ -760,13 +1033,54 @@ QueryAssistantResponseTypeDef = TypedDict(
     },
 )
 
-RecommendationDataTypeDef = TypedDict(
-    "RecommendationDataTypeDef",
+QueryRecommendationTriggerDataTypeDef = TypedDict(
+    "QueryRecommendationTriggerDataTypeDef",
+    {
+        "text": str,
+    },
+    total=False,
+)
+
+_RequiredRecommendationDataTypeDef = TypedDict(
+    "_RequiredRecommendationDataTypeDef",
     {
         "document": "DocumentTypeDef",
         "recommendationId": str,
-        "relevanceLevel": NotRequired[RelevanceLevelType],
-        "relevanceScore": NotRequired[float],
+    },
+)
+_OptionalRecommendationDataTypeDef = TypedDict(
+    "_OptionalRecommendationDataTypeDef",
+    {
+        "relevanceLevel": RelevanceLevelType,
+        "relevanceScore": float,
+        "type": Literal["KNOWLEDGE_CONTENT"],
+    },
+    total=False,
+)
+
+
+class RecommendationDataTypeDef(
+    _RequiredRecommendationDataTypeDef, _OptionalRecommendationDataTypeDef
+):
+    pass
+
+
+RecommendationTriggerDataTypeDef = TypedDict(
+    "RecommendationTriggerDataTypeDef",
+    {
+        "query": "QueryRecommendationTriggerDataTypeDef",
+    },
+    total=False,
+)
+
+RecommendationTriggerTypeDef = TypedDict(
+    "RecommendationTriggerTypeDef",
+    {
+        "data": "RecommendationTriggerDataTypeDef",
+        "id": str,
+        "recommendationIds": List[str],
+        "source": RecommendationSourceTypeType,
+        "type": Literal["QUERY"],
     },
 )
 
@@ -780,8 +1094,9 @@ RemoveKnowledgeBaseTemplateUriRequestRequestTypeDef = TypedDict(
 RenderingConfigurationTypeDef = TypedDict(
     "RenderingConfigurationTypeDef",
     {
-        "templateUri": NotRequired[str],
+        "templateUri": str,
     },
+    total=False,
 )
 
 ResponseMetadataTypeDef = TypedDict(
@@ -795,33 +1110,71 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
-ResultDataTypeDef = TypedDict(
-    "ResultDataTypeDef",
+_RequiredResultDataTypeDef = TypedDict(
+    "_RequiredResultDataTypeDef",
     {
         "document": "DocumentTypeDef",
         "resultId": str,
-        "relevanceScore": NotRequired[float],
     },
 )
+_OptionalResultDataTypeDef = TypedDict(
+    "_OptionalResultDataTypeDef",
+    {
+        "relevanceScore": float,
+    },
+    total=False,
+)
 
-SearchContentRequestRequestTypeDef = TypedDict(
-    "SearchContentRequestRequestTypeDef",
+
+class ResultDataTypeDef(_RequiredResultDataTypeDef, _OptionalResultDataTypeDef):
+    pass
+
+
+_RequiredSearchContentRequestRequestTypeDef = TypedDict(
+    "_RequiredSearchContentRequestRequestTypeDef",
     {
         "knowledgeBaseId": str,
         "searchExpression": "SearchExpressionTypeDef",
-        "maxResults": NotRequired[int],
-        "nextToken": NotRequired[str],
     },
 )
+_OptionalSearchContentRequestRequestTypeDef = TypedDict(
+    "_OptionalSearchContentRequestRequestTypeDef",
+    {
+        "maxResults": int,
+        "nextToken": str,
+    },
+    total=False,
+)
 
-SearchContentRequestSearchContentPaginateTypeDef = TypedDict(
-    "SearchContentRequestSearchContentPaginateTypeDef",
+
+class SearchContentRequestRequestTypeDef(
+    _RequiredSearchContentRequestRequestTypeDef, _OptionalSearchContentRequestRequestTypeDef
+):
+    pass
+
+
+_RequiredSearchContentRequestSearchContentPaginateTypeDef = TypedDict(
+    "_RequiredSearchContentRequestSearchContentPaginateTypeDef",
     {
         "knowledgeBaseId": str,
         "searchExpression": "SearchExpressionTypeDef",
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
+_OptionalSearchContentRequestSearchContentPaginateTypeDef = TypedDict(
+    "_OptionalSearchContentRequestSearchContentPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class SearchContentRequestSearchContentPaginateTypeDef(
+    _RequiredSearchContentRequestSearchContentPaginateTypeDef,
+    _OptionalSearchContentRequestSearchContentPaginateTypeDef,
+):
+    pass
+
 
 SearchContentResponseTypeDef = TypedDict(
     "SearchContentResponseTypeDef",
@@ -839,24 +1192,51 @@ SearchExpressionTypeDef = TypedDict(
     },
 )
 
-SearchSessionsRequestRequestTypeDef = TypedDict(
-    "SearchSessionsRequestRequestTypeDef",
+_RequiredSearchSessionsRequestRequestTypeDef = TypedDict(
+    "_RequiredSearchSessionsRequestRequestTypeDef",
     {
         "assistantId": str,
         "searchExpression": "SearchExpressionTypeDef",
-        "maxResults": NotRequired[int],
-        "nextToken": NotRequired[str],
     },
 )
+_OptionalSearchSessionsRequestRequestTypeDef = TypedDict(
+    "_OptionalSearchSessionsRequestRequestTypeDef",
+    {
+        "maxResults": int,
+        "nextToken": str,
+    },
+    total=False,
+)
 
-SearchSessionsRequestSearchSessionsPaginateTypeDef = TypedDict(
-    "SearchSessionsRequestSearchSessionsPaginateTypeDef",
+
+class SearchSessionsRequestRequestTypeDef(
+    _RequiredSearchSessionsRequestRequestTypeDef, _OptionalSearchSessionsRequestRequestTypeDef
+):
+    pass
+
+
+_RequiredSearchSessionsRequestSearchSessionsPaginateTypeDef = TypedDict(
+    "_RequiredSearchSessionsRequestSearchSessionsPaginateTypeDef",
     {
         "assistantId": str,
         "searchExpression": "SearchExpressionTypeDef",
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
+_OptionalSearchSessionsRequestSearchSessionsPaginateTypeDef = TypedDict(
+    "_OptionalSearchSessionsRequestSearchSessionsPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class SearchSessionsRequestSearchSessionsPaginateTypeDef(
+    _RequiredSearchSessionsRequestSearchSessionsPaginateTypeDef,
+    _OptionalSearchSessionsRequestSearchSessionsPaginateTypeDef,
+):
+    pass
+
 
 SearchSessionsResponseTypeDef = TypedDict(
     "SearchSessionsResponseTypeDef",
@@ -870,20 +1250,32 @@ SearchSessionsResponseTypeDef = TypedDict(
 ServerSideEncryptionConfigurationTypeDef = TypedDict(
     "ServerSideEncryptionConfigurationTypeDef",
     {
-        "kmsKeyId": NotRequired[str],
+        "kmsKeyId": str,
     },
+    total=False,
 )
 
-SessionDataTypeDef = TypedDict(
-    "SessionDataTypeDef",
+_RequiredSessionDataTypeDef = TypedDict(
+    "_RequiredSessionDataTypeDef",
     {
         "name": str,
         "sessionArn": str,
         "sessionId": str,
-        "description": NotRequired[str],
-        "tags": NotRequired[Dict[str, str]],
     },
 )
+_OptionalSessionDataTypeDef = TypedDict(
+    "_OptionalSessionDataTypeDef",
+    {
+        "description": str,
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
+
+
+class SessionDataTypeDef(_RequiredSessionDataTypeDef, _OptionalSessionDataTypeDef):
+    pass
+
 
 SessionSummaryTypeDef = TypedDict(
     "SessionSummaryTypeDef",
@@ -898,8 +1290,9 @@ SessionSummaryTypeDef = TypedDict(
 SourceConfigurationTypeDef = TypedDict(
     "SourceConfigurationTypeDef",
     {
-        "appIntegrations": NotRequired["AppIntegrationsConfigurationTypeDef"],
+        "appIntegrations": "AppIntegrationsConfigurationTypeDef",
     },
+    total=False,
 )
 
 StartContentUploadRequestRequestTypeDef = TypedDict(
@@ -937,19 +1330,32 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-UpdateContentRequestRequestTypeDef = TypedDict(
-    "UpdateContentRequestRequestTypeDef",
+_RequiredUpdateContentRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateContentRequestRequestTypeDef",
     {
         "contentId": str,
         "knowledgeBaseId": str,
-        "metadata": NotRequired[Mapping[str, str]],
-        "overrideLinkOutUri": NotRequired[str],
-        "removeOverrideLinkOutUri": NotRequired[bool],
-        "revisionId": NotRequired[str],
-        "title": NotRequired[str],
-        "uploadId": NotRequired[str],
     },
 )
+_OptionalUpdateContentRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateContentRequestRequestTypeDef",
+    {
+        "metadata": Mapping[str, str],
+        "overrideLinkOutUri": str,
+        "removeOverrideLinkOutUri": bool,
+        "revisionId": str,
+        "title": str,
+        "uploadId": str,
+    },
+    total=False,
+)
+
+
+class UpdateContentRequestRequestTypeDef(
+    _RequiredUpdateContentRequestRequestTypeDef, _OptionalUpdateContentRequestRequestTypeDef
+):
+    pass
+
 
 UpdateContentResponseTypeDef = TypedDict(
     "UpdateContentResponseTypeDef",
